@@ -10,7 +10,7 @@ class code_execution_tab(TabBase):
 synapse_tag='GLU'
 synapse_var='W'
 
-combined = Network_UI.get_combined_syn_mats(n.afferent_synapses[synapse_tag], None,synapse_var)
+combined = get_combined_syn_mats(n.afferent_synapses[synapse_tag], None,synapse_var)
 
 for mat in combined.values():
 
@@ -42,7 +42,7 @@ print(num)
         #item.setCheckState(check)
         #self.timed_execution_model.appendRow(item)
 
-        self.code_execution_tab = Network_UI.Next_Tab('code exec')
+        self.code_execution_tab = Network_UI.Next_Tab('Code Exec.')
         self.comboBox = Network_UI.Add_element(QComboBox())
 
         self.txt_py_dict={}
@@ -51,16 +51,19 @@ print(num)
         self.txt_py_dict["show synapse matrices"] = self.sample_code1
         self.txt_py_dict["count synapses"] = self.sample_code2
 
-        try:
-            data_folder = get_data_folder(create_when_not_found=False)
-            for d in os.listdir(data_folder):
+        data_folder = get_data_folder(create_when_not_found=False)+'/scripts'
+
+        if not os.path.exists(data_folder):
+            os.mkdir(data_folder)
+
+        for d in os.listdir(data_folder):
+            try:
                 if '.py' in d:
                     with open(data_folder+'/'+d) as f:
                         self.txt_py_dict[d.replace('.py','')] = f.read()
+            except:
+                print("error in script", d)
 
-                    self.add_timed_script(d)
-        except:
-            pass
 
         for txt in self.txt_py_dict:
             self.comboBox.addItem(txt)
@@ -79,16 +82,19 @@ print(num)
         Network_UI.Next_H_Block()
 
         self.code_field=Network_UI.Add_element(QTextEdit())
+
+        self.code_field.setAcceptRichText(False)
+
         self.code_field.textChanged.connect(on_code_changed)
 
-        Network_UI.Next_H_Block(stretch=0.1)
+        Network_UI.Next_H_Block(stretch=1)
 
         self.exec_btn=Network_UI.Add_element(QPushButton('Execute'))
 
         def exec_btn_click(event):
             net = Network_UI.network
             network = net
-            n = Network_UI.network[Network_UI.neuron_select_group, 0]
+            n = Network_UI.selected_neuron_group()
             ng = n
             neurons = n
             neuron_group = n
@@ -97,12 +103,14 @@ print(num)
 
             print('code block executed successfuly!')
 
+            Network_UI.add_event('code execution')
+
         self.exec_btn.clicked.connect(exec_btn_click)
 
         self.save_btn_click = Network_UI.Add_element(QPushButton('Save Script'))
 
         def save(input_txt):
-            data_folder = get_data_folder(create_when_not_found=False)
+            data_folder = get_data_folder(create_when_not_found=False)+'/scripts'
             name=data_folder + '/'+input_txt+'.py'
             with open(name, "w") as f:
                 f.write(self.code_field.toPlainText())
@@ -118,61 +126,33 @@ print(num)
 
             self.code_field.setStyleSheet("QTextEdit { background-color: rgb(255, 255, 255); }")
 
-            self.add_timed_script(name)
+            #self.add_timed_script(name)
 
         def save_btn_click(event):
             Network_UI.text_input_dialog("Please name your script", 'save', save, self.comboBox.itemText(self.comboBox.currentIndex()).replace('.py',''))
 
         self.save_btn_click.clicked.connect(save_btn_click)
 
+        self.compiled = None
+        self.compiled_script_txt = ''
+        self.timestep_execute_cb = Network_UI.Add_element(QCheckBox('Execute every timestep'))
 
-        def timed_execution_add(number):#number is a string!
-            if number.isnumeric():
-                original_file = self.comboBox.itemText(self.comboBox.currentIndex())
-                end = original_file.find(']')
-                if end != -1:
-                    original_file = original_file[end+1:]
+    def update(self, Network_UI):
 
-                original_file = original_file.replace('[', '')
-                original_file = original_file.replace(']', '')
+        if self.timestep_execute_cb.isChecked():
 
-                new_file = '['+number+']'+original_file
+            net = Network_UI.network
+            network = net
+            n = Network_UI.selected_neuron_group()
+            ng = n
+            neurons = n
+            neuron_group = n
 
-                save(new_file)
-            else:
-                print('no valid iteration number!')
-
-        self.timed_execution_btn_click = Network_UI.Add_element(QPushButton('Add to timed execution'))
-
-        def timed_execution_btn_click(event):
-            Network_UI.text_input_dialog("Enter execution iteration number", 'add', timed_execution_add, "10000")
-
-        self.timed_execution_btn_click.clicked.connect(timed_execution_btn_click)
-
-
-
-
-    def add_timed_script(self, file_name):
-        return
-        '''
-        #
-        if '[' in file_name and ']' in file_name:
-            print(file_name)
-            name = file_name.split('/')[-1].replace('.py', '')
-
-            execution_time = int(name.split(']')[0].replace('[', ''))
-            base_name = name.split(']')[1]
-
-            #self.timed_execution_list_view
-
-            item = QtGui.QStandardItem(str(execution_time)+' | '+base_name)
-            item.setCheckable(True)
-            check = QtCore.Qt.Checked# if checked else QtCore.Qt.Unchecked
-            item.setCheckState(check)
-            self.timed_execution_model.appendRow(item)
-
-            #self.Network_UI.Add_Sidebar_Element([QLabel(str(execution_time)), QCheckBox(base_name), QPushButton('-')], percentages=[10, 85, 5])
-        '''
+            code = self.code_field.toPlainText()
 
+            if self.compiled is None or self.compiled_script_txt != code:
+                self.compiled = compile(code, '<string>', 'exec')
+                self.compiled_script_txt = code
 
+            exec(self.compiled)
 
