@@ -3,45 +3,62 @@ from PymoNNto.NetworkBehaviour.Recorder.Recorder import *
 
 #from Testing.Common.Grammar_Helper import *
 
+class sidebar_module_quick_access(TabBase):
+
+    def __init__(self, module_label='my_module', module_tag='module_tag'):
+        self.module_label = module_label
+        self.module_tag = module_tag
+
+
+    def initialize(self, Network_UI):
+        if Network_UI.network['STDP', 0] is not None:
+            def learning_on_off(event):
+                Network_UI.network.set_mechanisms(['STDP'], self.stdp_cb.isChecked())
+                Network_UI.add_event('STDP ('+str(self.stdp_cb.isChecked())+')')
+
+            self.stdp_cb = QCheckBox()
+            self.stdp_cb.setText('STDP')
+            self.stdp_cb.setChecked(Network_UI.network['STDP',0].behaviour_enabled)
+            self.stdp_cb.stateChanged.connect(learning_on_off)
+            Network_UI.Add_Sidebar_Element(self.stdp_cb)
+
+        if Network_UI.network['Text_Activator', 0] is not None:
+            def activator_on_off(event):
+                Network_UI.network['Text_Activator', 0].behaviour_enabled = self.act_cb.isChecked()
+                Network_UI.add_event('Text_Activator (' + str(self.act_cb.isChecked()) + ')')
+
+            self.act_cb = QCheckBox()
+            self.act_cb.setText('Text input:')
+            self.act_cb.setChecked(Network_UI.network['Text_Activator',0].behaviour_enabled)
+            self.act_cb.stateChanged.connect(activator_on_off)
+            Network_UI.Add_Sidebar_Element(self.act_cb)
+
+
+
 class sidebar_grammar_module_new(TabBase):
 
     def __init__(self, text_length=30):
         self.text_length = text_length
 
     def initialize(self, Network_UI):
-        def learning_on_off(event):
-            Network_UI.network.set_mechanisms(['STDP'], self.stdp_cb.isChecked())
 
-        self.stdp_cb = QCheckBox()
-        self.stdp_cb.setText('STDP')
-        self.stdp_cb.setChecked(True)
-        self.stdp_cb.stateChanged.connect(learning_on_off)
-        Network_UI.Add_Sidebar_Element(self.stdp_cb)
+        if Network_UI.network['Text_Activator', 0] is not None:
+            self.inp_text_label = QLabel(Network_UI.main_window)
+            Network_UI.Add_Sidebar_Element(self.inp_text_label, stretch=2)
+            self.inp_text_label.setText('')
+            self.inp_text_label.setFont(QFont("Courier"))
+            self.inp_text_label.setToolTip('current network input')
 
-        def activator_on_off(event):
-            Network_UI.network['Text_Activator', 0].behaviour_enabled = self.act_cb.isChecked()
+        if Network_UI.network['Text_Reconstructor', 0] is not None:
+            rl = QLabel(Network_UI.main_window)
+            Network_UI.Add_Sidebar_Element(rl, stretch=2)
+            rl.setText('Reconstruction:')
 
-        self.act_cb = QCheckBox()
-        self.act_cb.setText('Text input:')
-        self.act_cb.setChecked(True)
-        self.act_cb.stateChanged.connect(activator_on_off)
-        Network_UI.Add_Sidebar_Element(self.act_cb)
-
-        self.inp_text_label = QLabel(Network_UI.main_window)
-        Network_UI.Add_Sidebar_Element(self.inp_text_label, stretch=0.2)
-        self.inp_text_label.setText('')
-        self.inp_text_label.setFont(QFont("Courier"))
-        self.inp_text_label.setToolTip('current network input')
-
-        rl = QLabel(Network_UI.main_window)
-        Network_UI.Add_Sidebar_Element(rl, stretch=0.2)
-        rl.setText('Reconstruction:')
-
-        self.recon_text_label = QLabel(Network_UI.main_window)
-        Network_UI.Add_Sidebar_Element(self.recon_text_label, stretch=0.2)
-        self.recon_text_label.setText('')
-        self.recon_text_label.setFont(QFont("Courier"))
-        self.recon_text_label.setToolTip('simple reconstruction text')
+            self.recon_text_label = QLabel(Network_UI.main_window)
+            Network_UI.Add_Sidebar_Element(self.recon_text_label, stretch=2)
+            self.recon_text_label.setText('')
+            self.recon_text_label.setFont(QFont("Courier"))
+            self.recon_text_label.setToolTip('simple reconstruction text')
 
     def update(self, Network_UI):
 
