@@ -56,6 +56,8 @@ class UI_Base(QApplication):
 
         self.main_window = QWidget()
         self.main_window.keyPressEvent = self.keyPressEvent
+        self.main_window.keyReleaseEvent = self.keyReleaseEvent
+        self.control_key_down=False
 
         self.init_QT_Window(label, create_sidebar)
         quit = QAction("Quit", self.main_window)
@@ -153,7 +155,7 @@ class UI_Base(QApplication):
         else:
             return curves
 
-    def Next_Tab(self, title='', stretch=1 , create_h_block=True):
+    def Next_Tab(self, title='', stretch=100 , create_h_block=True):
 
         main_tab_container = QWidget()
 
@@ -178,7 +180,7 @@ class UI_Base(QApplication):
         return main_tab_container
 
 
-    def Next_H_Block(self,stretch=1):
+    def Next_H_Block(self,stretch=100):
         self.current_H_block = QHBoxLayout()
         self.visualization_layout.addLayout(self.current_H_block, stretch=stretch)
 
@@ -230,7 +232,7 @@ class UI_Base(QApplication):
         #cont.addWidget(vsplit)
 
         self.main_split.addWidget(self.vsplit)
-        self.main_split.setSizes([1, 18])
+        self.main_split.setSizes([300, 800])
         #self.main_h_layout.addLayout(cont, stretch=8)
 
 
@@ -246,6 +248,16 @@ class UI_Base(QApplication):
 
         #self.Next_Tab('Main')
 
+        self.tabs.currentChanged.connect(self._onTabChange)
+        self.tabs2.currentChanged.connect(self._onTabChange)
+        self.tabs3.currentChanged.connect(self._onTabChange)
+        self.tabs4.currentChanged.connect(self._onTabChange)
+
+    def _onTabChange(self, i):
+        self.on_tab_change(i)
+
+    def on_tab_change(self, i):
+        return #overwrite
 
     def create_detail_label_pixmap(self):
         self.detail_qlabel = QLabel()
@@ -293,7 +305,7 @@ class UI_Base(QApplication):
     def Add_Sidebar_Spacing(self):
         self.Add_Sidebar_Element(QLabel())
 
-    def Add_Sidebar_Element(self, elements=[], percentages=None, stretch=1, return_h_layout=False):
+    def Add_Sidebar_Element(self, elements=[], percentages=None, stretch=100, return_h_layout=False):
         if type(elements) is not list: elements=[elements]
         if percentages is None: percentages=[1 for _ in elements]
 
@@ -311,8 +323,14 @@ class UI_Base(QApplication):
         else:
             return elements
 
+    def keyReleaseEvent(self, event):
+        if event.key() == Qt.Key_Control:
+            self.control_key_down=False
 
     def keyPressEvent(self, event):
+        if event.key() == Qt.Key_Control:
+            self.control_key_down=True
+
         if event.key() in [Qt.Key_N, Qt.Key_C, Qt.Key_T, Qt.Key_M]:
             self.text_input_dialog('Please enter Note:', 'set note', self.set_note, default_text='-')
 
