@@ -32,7 +32,7 @@ class Network(NetworkObjectBase):
                 print('activating', key)
             else:
                 print('deactivating', key)
-            for obj in self.all_behaviour_objects():
+            for obj in self.all_objects():
                 for mechansim in obj[key]:
                     mechansim.behaviour_enabled = enabeled #changed (active)
 
@@ -44,18 +44,18 @@ class Network(NetworkObjectBase):
         self.set_mechanisms(keys, True)
 
     def recording_off(self):
-        for obj in self.all_behaviour_objects():
+        for obj in self.all_objects():
             obj.recording = False
 
     def recording_on(self):
-        for obj in self.all_behaviour_objects():
+        for obj in self.all_objects():
             obj.recording = True
 
-    def all_behaviour_objects(self):
+    def all_objects(self):
         return [self]+self.NeuronGroups+self.SynapseGroups
 
     def clear_recorder(self, keys=None):
-        for obj in self.all_behaviour_objects():
+        for obj in self.all_objects():
             for key in obj.behaviour:
                 if (keys is None or key in keys) and hasattr(obj.behaviour[key], 'clear_recorder'):
                     obj.behaviour[key].clear_recorder()
@@ -63,7 +63,7 @@ class Network(NetworkObjectBase):
     def set_gene_variables(self, info=True, storage_manager=None):
         current_genome = {}
 
-        for obj in self.all_behaviour_objects():
+        for obj in self.all_objects():
             for key in obj.behaviour:
                 b = obj.behaviour[key]
                 current_genome.update(b.set_gene_variables())
@@ -72,7 +72,9 @@ class Network(NetworkObjectBase):
             print('genome:', current_genome)
 
         if storage_manager is not None:
+            print(current_genome)
             storage_manager.save_param(key='evolution_params', value=current_genome)
+            storage_manager.save_param_dict(current_genome)
 
     def __str__(self):
         neuron_count = np.sum(np.array([ng.size for ng in self.NeuronGroups]))
@@ -114,20 +116,26 @@ class Network(NetworkObjectBase):
         for sg in self.SynapseGroups:
             result += sg[key]
 
+        for am in self.analysis_modules:
+            result += am[key]
+
         return result
 
-    def save_descriptions(self, storage_manager=None):
-        if storage_manager is not None:
-            return #todo: implement
-            #storage_manager.save_param(key, value, section='Parameters')
+    #def save_descriptions(self, storage_manager=None):
+    #    if storage_manager is not None:
+    #        return
+    #        #storage_manager.save_param(key, value, section='Parameters')
 
 
-    def initialize(self, info=False, warnings=True, storage_manager=None):
+    def initialize(self, info=True, warnings=True, storage_manager=None):
 
         self.set_gene_variables(info=info, storage_manager=storage_manager)
 
         if info:
-            print(str(self))
+            desc=str(self)
+            print(desc)
+            if storage_manager is not None:
+                storage_manager.save_param('info', desc)
 
         #self.old_param_list = self.get_all_params()
 
@@ -148,7 +156,7 @@ class Network(NetworkObjectBase):
 
         self.check_unique_tags(warnings)
 
-        self.save_descriptions(storage_manager)
+        #self.save_descriptions(storage_manager)
 
     def check_unique_tags(self,warnings=True):
         unique_tags=[]
@@ -163,7 +171,7 @@ class Network(NetworkObjectBase):
                 new_tag=ng.tags[0]+chr(97+counts)
                 unique_tags.append(ng.tags[0])
                 if warnings:
-                    print('Warning: NeuronGroup Tag "'+ng.tags[0]+'" already in use. The first Tag of an Object should be unique and will be renamed to "'+new_tag+'". Multiple Tags can be sperated with a "," (NeuronGroup(..., tag="tag1,tag2,..."))')
+                    print('Warning: NeuronGroup Tag "'+ng.tags[0]+'" already in use. The first Tag of an Object should be unique and will be renamed to "'+new_tag+'". Multiple Tags can be separated with a "," (NeuronGroup(..., tag="tag1,tag2,..."))')
                 ng.tags[0] = new_tag
 
             else:
@@ -190,13 +198,6 @@ class Network(NetworkObjectBase):
     def add_behaviours_to_object(self, behaviours, net_obj):
         self.clear_tag_cache()
         original = behaviours
-        #if type(behaviours) == list:
-        #    start_key = self.behaviour_timesteps[-1]
-        #    d = {}
-        #    for b in behaviours:
-        #        start_key += 1
-        #        d[start_key] = b
-        #    behaviours = d
 
         for key in behaviours:
             net_obj.behaviour[key] = behaviours[key]
@@ -228,7 +229,7 @@ class Network(NetworkObjectBase):
 
     def clear_tag_cache(self):
 
-        for obj in self.all_behaviour_objects():
+        for obj in self.all_objects():
             obj.clear_cache()
 
             for k in obj.behaviour:
@@ -238,7 +239,7 @@ class Network(NetworkObjectBase):
     def set_variables(self):
         for timestep in self.behaviour_timesteps:
 
-            for obj in self.all_behaviour_objects():
+            for obj in self.all_objects():
 
                 if timestep in obj.behaviour:
                     if not obj.behaviour[timestep].set_variables_on_init:
@@ -290,7 +291,7 @@ class Network(NetworkObjectBase):
         self.iteration += 1
         for timestep in self.behaviour_timesteps:
 
-            for net_obj in self.all_behaviour_objects():
+            for net_obj in self.all_objects():
                 net_obj.iteration=self.iteration
                 if timestep in net_obj.behaviour and net_obj.behaviour[timestep].behaviour_enabled:
                     if measure_behaviour_execution_time:
@@ -365,7 +366,7 @@ class Network(NetworkObjectBase):
                 print('\r{}xBatch: {}/{} ({}%) {:.3f}ms'.format(block_iterations,t+1, outside_it, int(100/outside_it*(t+1)),time_diff), end='')#, end='')
 
             if batch_progress_update_func is not None:
-                batch_progress_update_func((t+1.0)/int(outside_it)*100.0)
+                batch_progress_update_func((t+1.0)/int(outside_it)*100.0, self)
 
         for i in range(iterations%batch_size):
             self.simulate_iteration()
