@@ -3,7 +3,11 @@ import copy
 
 class NeuronGroup(NetworkObjectBase):
 
-    def __init__(self, size, behaviour, net, tag=None):
+    def __init__(self, size, behaviour, net, tag=None, color=None):
+
+        if tag is None and net is not None:
+            tag = 'NeuronGroup_'+str(len(net.NeuronGroups)+1)
+
         super().__init__(tag=tag)
         self.add_tag('ng')
 
@@ -21,6 +25,7 @@ class NeuronGroup(NetworkObjectBase):
         if net is not None:
             net.NeuronGroups.append(self)
             self.network = net
+            setattr(net, self.tags[0], self)
 
 
         self.size = size
@@ -47,8 +52,8 @@ class NeuronGroup(NetworkObjectBase):
 
         self.id = np.arange(self.size)
 
-
-        #self.tags = []
+        if color is not None:
+            self.color = color
 
     #do only use before initialization!!!
     #after initialization use Netork.add_behaviours_to_neuron_group(...)
@@ -74,6 +79,9 @@ class NeuronGroup(NetworkObjectBase):
         #        if syn not in result:
         #            result += syn[key]
 
+        for am in self.analysis_modules:
+            result += am[key]
+
         return result
 
     def get_modification_value(self, key):
